@@ -6,7 +6,7 @@ from msgpack import unpackb, packb
 from tuneflow_devkit.validation_utils import validate_plugin, find_match_plugin_info
 from collections import defaultdict
 from fastapi import FastAPI, Request, Response, Depends, BackgroundTasks
-from pathlib import PosixPath
+from pathlib import Path
 import asyncio
 import functools
 from fastapi.middleware.cors import CORSMiddleware
@@ -46,7 +46,7 @@ class Runner:
                         plugin_class.provider_id() == plugin_info["providerId"] and plugin_class.plugin_id() ==
                         plugin_info["pluginId"] for plugin_class in plugin_class_list):
                     raise Exception(
-                        f'Plugin {plugin_info["providerId"]} {plugin_info["pluginInfo"]} has no corresponding source code in the plugin list')
+                        f'Plugin {plugin_info["providerId"]} {plugin_info["pluginId"]} has no corresponding source code in the plugin list')
 
     def start(self, path_prefix='/', config=None):
         '''
@@ -68,6 +68,7 @@ class Runner:
         )
 
         async_config = config["async"] if config and "async" in config else None
+        exception_handler = config["exception"]["handler"] if config and "exception" in config and "handler" in config["exception"] else None
 
         @app.middleware("http")
         async def add_vary_origin_header(request: Request, call_next):
@@ -75,9 +76,9 @@ class Runner:
             response.headers["Vary"] = 'Origin'
             return response
 
-        get_info_path = str(PosixPath(path_prefix).joinpath('plugin-bundle-info'))
-        init_plugin_path = str(PosixPath(path_prefix).joinpath('init-plugin-params'))
-        run_plugin_path = str(PosixPath(path_prefix).joinpath('jobs'))
+        get_info_path = str(Path(path_prefix).joinpath('plugin-bundle-info'))
+        init_plugin_path = str(Path(path_prefix).joinpath('init-plugin-params'))
+        run_plugin_path = str(Path(path_prefix).joinpath('jobs'))
 
         def init_plugin_task(plugin_class: Type[TuneflowPlugin], song: Song):
             try:
@@ -98,7 +99,8 @@ class Runner:
             except Exception as e:
                 print(traceback.format_exc())
                 return {
-                    "status": "ERROR"
+                    "status": "ERROR",
+                    "error": e
                 }
             return {
                 "status": "OK",
@@ -108,8 +110,13 @@ class Runner:
         async def run_plugin_async_task(plugin_class: Type[TuneflowPlugin], song, params, job_id: str, store_uploader):
             # TODO: Revisit to see if we can call run_plugin_task directly.
             response = await asyncio.get_event_loop().run_in_executor(None,  functools.partial(run_plugin_task, plugin_class=plugin_class, song=song, params=params))
+            error = response["error"] if "error" in response else None
+            if "error" in response:
+                del response["error"]
             response["jobId"] = job_id
             store_uploader(job_id, packb(response))
+            if response["status"] == "ERROR" and error is not None and exception_handler is not None:
+                exception_handler(error)
 
         def find_plugin_by_id(plugin_class_list: List[Type[TuneflowPlugin]], provider_id, plugin_id):
             for plugin_class in plugin_class_list:
@@ -158,6 +165,11 @@ class Runner:
                 }), headers={"Content-Type": "application/octet-stream"})
             else:
                 result = await asyncio.get_event_loop().run_in_executor(None,  functools.partial(run_plugin_task, plugin_class=plugin_class, song=song, params=params))
+                if result["status"] == "ERROR" and "error" in result:
+                    if exception_handler:
+                        exception_handler(result["error"])
+                if "error" in result:
+                    del result["error"]
                 return Response(packb(result), headers={"Content-Type": "application/octet-stream"})
 
         return app
